#[repr(u32)]pub enum InputDeviceType {
Generic = 1,
Semantical = 2,
}Expand description
Input-device class declared by the official SDK.
Variants
Generic = 1
Generic device whose inputs can be bound in the game UI.
Semantical = 2
Device whose input names map directly to supported game mixes.
Implementations