InputDeviceSpec

Struct InputDeviceSpec 

pub struct InputDeviceSpec { /* private fields */ }
Explicit declaration of one SCS input device.

Implementations

Source

impl InputDeviceSpec

pub const fn new( name: &'static str, display_name: &'static str, device_type: InputDeviceType, inputs: &'static [InputSpec], ) -> Self

Creates a device declaration without the optional activity callback.

Call InputDeviceSpec::with_activity_notifications when the product needs explicit activation and deactivation notifications.

pub const fn with_activity_notifications(self) -> Self

Explicitly requests the optional SCS device-activity callback.

pub const fn name(self) -> &'static str

Unique device configuration name.

pub const fn display_name(self) -> &'static str

Human-facing device name.

pub const fn device_type(self) -> InputDeviceType

Generic bindable or semantical device class.

pub const fn inputs(self) -> &'static [InputSpec]

Inputs in the exact zero-based order used by InputIndex.

pub const fn activity_notifications(self) -> bool

Whether the runtime should register the optional activity callback.