pub struct InputDeviceSpec { /* private fields */ }Expand description
Explicit declaration of one SCS input device.
Implementations
Sourceimpl InputDeviceSpec
impl InputDeviceSpec
Sourcepub const fn new(
name: &'static str,
display_name: &'static str,
device_type: InputDeviceType,
inputs: &'static [InputSpec],
) -> Self
pub const fn new( name: &'static str, display_name: &'static str, device_type: InputDeviceType, inputs: &'static [InputSpec], ) -> Self
Creates a device declaration without the optional activity callback.
Call InputDeviceSpec::with_activity_notifications when the product
needs explicit activation and deactivation notifications.
Sourcepub const fn with_activity_notifications(self) -> Self
pub const fn with_activity_notifications(self) -> Self
Explicitly requests the optional SCS device-activity callback.
Sourcepub const fn display_name(self) -> &'static str
pub const fn display_name(self) -> &'static str
Human-facing device name.
Sourcepub const fn device_type(self) -> InputDeviceType
pub const fn device_type(self) -> InputDeviceType
Generic bindable or semantical device class.
Sourcepub const fn inputs(self) -> &'static [InputSpec]
pub const fn inputs(self) -> &'static [InputSpec]
Inputs in the exact zero-based order used by InputIndex.
Sourcepub const fn activity_notifications(self) -> bool
pub const fn activity_notifications(self) -> bool
Whether the runtime should register the optional activity callback.